import React, { FC } from 'react';
import ModalNative from 'react-native-modal';
import { View } from 'react-native';
import { AreaWrapper } from '../areaWrapper';
import { getThemeColorByDefaultColor } from '../../../../utils';
import { borderRadiusSizes } from '../../../constants';

interface Props {
  modalHeight?: string | number;
  backgroundColor?: string;
  children: JSX.Element | JSX.Element[]
  isVisible: boolean;
  onModalHide: () => void;
}

export const BottomSheetWrapper: FC<Props> = ({
  modalHeight = '50%',
  backgroundColor= getThemeColorByDefaultColor('background', 'extraLight'),
  children,
  isVisible,
  onModalHide,
}) => {
  return (
    <AreaWrapper topColor={'transparent'} barStyle={'light-content'}>
      <ModalNative
        backdropColor={getThemeColorByDefaultColor('text', 'extraDark')}
        backdropOpacity={0}
        isVisible={isVisible}
        onSwipeComplete={onModalHide}
        onBackdropPress={onModalHide}
        useNativeDriverForBackdrop
        swipeDirection={['down']}
        propagateSwipe={true}
        style={{ margin: 0, justifyContent: 'flex-end' }}
      >
        <View
          style={
            {
              height: modalHeight,
              backgroundColor,
              borderTopLeftRadius: borderRadiusSizes.medium,
              borderTopRightRadius: borderRadiusSizes.medium,
            }
          }
        >
          {children}
        </View>
      </ModalNative>
    </AreaWrapper>
  );
};
