import React, { FC } from 'react';
import { TouchableOpacity, View } from 'react-native';
import { CalendarControlsProps, HandleOnDatePress, PressControlOptions } from './calendarControlsModel';
import { ChevronLeftIcon, ChevronRightIcon, ChevronDoubleLeftIcon, ChevronDoubleRightIcon, LabelMediumText } from '../../../../atoms';
import { styles } from './styles';

export const CalendarControls: FC<CalendarControlsProps> = ({
  monthName,
  monthNumber,
  yearData,
  onGoToMonthNumberAndYear,
  disabled,
}) => {
  const handleOnMonthNumberAndYearPress: HandleOnDatePress = (pressControlOption) => {
    onGoToMonthNumberAndYear?.({ 
      selectedMonthNumber: monthNumber, 
      selectedYear: yearData, 
      pressControlOption, 
    });
  };

  return (
    <View style={styles.headerControlsWrapper}>
      <View style={styles.headerControls}>
        <TouchableOpacity
          style={[styles.controlPress, styles.controlPressRightSeparator]}
          disabled={disabled}
          onPress={() => handleOnMonthNumberAndYearPress(PressControlOptions.PREVIOUS_YEAR)}
        >
          <ChevronDoubleLeftIcon width={styles.icon.size} color={styles.icon.color} />
        </TouchableOpacity>
        <TouchableOpacity
          style={styles.controlPress}
          disabled={disabled}
          onPress={() => handleOnMonthNumberAndYearPress(PressControlOptions.PREVIOUS_MONTH)}
        >
          <ChevronLeftIcon width={styles.icon.size} color={styles.icon.color} />
        </TouchableOpacity>
      </View>
    
      <LabelMediumText>{`${monthName} ${yearData}`}</LabelMediumText>
    
      <View style={styles.headerControls}>
        <TouchableOpacity
          style={[styles.controlPress, styles.controlPressRightSeparator]}
          disabled={disabled}
          onPress={() => handleOnMonthNumberAndYearPress(PressControlOptions.NEXT_MONTH)}
        >
          <ChevronRightIcon width={styles.icon.size} color={styles.icon.color} />
        </TouchableOpacity>
        <TouchableOpacity
          style={styles.controlPress}
          disabled={disabled}
          onPress={() => handleOnMonthNumberAndYearPress(PressControlOptions.NEXT_YEAR)}
        >
          <ChevronDoubleRightIcon width={styles.icon.size} color={styles.icon.color} />
        </TouchableOpacity>
      </View>
    </View>
  );
};

