import React, { FC } from 'react';
import { TouchableOpacity, ViewStyle } from 'react-native';
import { Body2MediumText } from '../../../../atoms';
import { DateCategory, DateNumberOfTheMonth } from '../../calendarModel';
import { styles } from './styles';

interface CalendarDayProps {
  category: DateCategory[];
  dateNumber: DateNumberOfTheMonth;
  onDateNumberClick?: (dateNumber: DateNumberOfTheMonth) => void;
}

export const CalendarDate: FC<CalendarDayProps> = ({
  category,
  dateNumber,
  onDateNumberClick,
}) => {
  const isSpecialDate: boolean = category.some(category => DateCategory.SPECIAL === category);
  const stylesCategory: ViewStyle[] = category.map(category => styles[category]);

  return (
    <TouchableOpacity
      style={[styles.calendarDateWrapper, ...stylesCategory]}
      onPress={() => onDateNumberClick?.(dateNumber)}
    >
      {isSpecialDate && (
        <Body2MediumText color={styles.defaultText.color}>
          {dateNumber}
        </Body2MediumText>
      )}
      {!isSpecialDate && (
        <Body2MediumText color={styles.specialText.color}>
          {dateNumber}
        </Body2MediumText>
      )}
    </TouchableOpacity>
  );
};
